@@ -62,6 +62,9 @@ FAILEDOPERATION_DBOPERATIONACTIONERROR = 'FailedOperation.DBOperationActionError
 # Failed to query database proxy.
 FAILEDOPERATION_DESCRIBEPROXYGROUPERROR = 'FailedOperation.DescribeProxyGroupError'
 
+# Unsupported operation
+FAILEDOPERATION_FAILEDOPERATIONERROR = 'FailedOperation.FailedOperationError'
+
 # An error occurred while obtaining permissions.
 FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'
 
@@ -86,6 +89,9 @@ FAILEDOPERATION_PROXYGROUPSTATUSERROR = 'FailedOperation.ProxyGroupStatusError'
 # Log query failed.
 FAILEDOPERATION_QUERYLOGERROR = 'FailedOperation.QueryLogError'
 
+# The proxy is being created or already exists. You cannot create it again.
+FAILEDOPERATION_REPEATCREATEPROXYERROR = 'FailedOperation.RepeatCreateProxyError'
+
 # Exception with the backend request for the service. Please contact customer service.
 FAILEDOPERATION_RESPONSEVALUEERROR = 'FailedOperation.ResponseValueError'
 
@@ -104,6 +110,12 @@ FAILEDOPERATION_TIMEOUTERROR = 'FailedOperation.TimeoutError'
 # This type of operations cannot be performed.
 FAILEDOPERATION_TYPEINCONFLICT = 'FailedOperation.TypeInConflict'
 
+# The IP has been occupied.
+FAILEDOPERATION_VPCIPINUSEERROR = 'FailedOperation.VpcIpInUseError'
+
+# The IP doesn’t exist in the subnet.
+FAILEDOPERATION_VPCIPNOTINSUBNETERROR = 'FailedOperation.VpcIpNotInSubnetError'
+
 # An internal error occurred.
 INTERNALERROR = 'InternalError'
 
@@ -413,9 +425,21 @@ OPERATIONDENIED_NOTSUPPORTBASIC = 'OperationDenied.NotSupportBasic'
 # The host information of the local root account cannot be modified.
 OPERATIONDENIED_NOTSUPPORTMODIFYLOCALROOTHOSTERROR = 'OperationDenied.NotSupportModifyLocalRootHostError'
 
+# Operation denied
+OPERATIONDENIED_OPERATIONDENIEDERROR = 'OperationDenied.OperationDeniedError'
+
 # There are other orders being submitted. Please try again later.
 OPERATIONDENIED_OTHERODERINPROCESS = 'OperationDenied.OtherOderInProcess'
 
+# The number of the proxy addresses exceeds the limit.
+OPERATIONDENIED_PROXYADDRESSLIMITERROR = 'OperationDenied.ProxyAddressLimitError'
+
+# Proxy address is not found.
+OPERATIONDENIED_PROXYADDRESSNOTFUND = 'OperationDenied.ProxyAddressNotFund'
+
+# The number of the proxy nodes exceeds the limit.
+OPERATIONDENIED_PROXYNODECOUNTLIMITERROR = 'OperationDenied.ProxyNodeCountLimitError'
+
 # This operation is not allowed during database proxy upgrade task.
 OPERATIONDENIED_PROXYUPGRADETASKSTATUSERROR = 'OperationDenied.ProxyUpgradeTaskStatusError'
 
@@ -428,6 +452,9 @@ OPERATIONDENIED_SUBACCOUNTOPERATIONDENIED = 'OperationDenied.SubAccountOperation
 # This instance is not refundable.
 OPERATIONDENIED_UNSUPPORTREFUNDERROR = 'OperationDenied.UnSupportRefundError'
 
+# Creating a proxy address is not supported.
+OPERATIONDENIED_UNSUPPORTCREATEADDRESSERROR = 'OperationDenied.UnsupportCreateAddressError'
+
 # The audit feature cannot be enabled.
 OPERATIONDENIED_UNSUPPORTOPENAUDITERROR = 'OperationDenied.UnsupportOpenAuditError'
 
@@ -455,6 +482,9 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # The instance cannot be found. Please check whether your instance status is normal.
 RESOURCENOTFOUND_CDBINSTANCENOTFOUNDERROR = 'ResourceNotFound.CdbInstanceNotFoundError'
 
+# High-availability instance doesn’t exist.
+RESOURCENOTFOUND_INSTANCENOTFOUNDERROR = 'ResourceNotFound.InstanceNotFoundError'
+
 # The instance does not exist.
 RESOURCENOTFOUND_INSTANCENOTFUNDERROR = 'ResourceNotFound.InstanceNotFundError'
 
