@@ -80,6 +80,24 @@ INVALIDPARAMETER_BANDWIDTHALERTCOUNTERMEASURECONFLICTORIGINTYPE = 'InvalidParame
 # Invalid domain name status.
 INVALIDPARAMETER_CDNSTATUSINVALIDDOMAIN = 'InvalidParameter.CDNStatusInvalidDomain'
 
+# Inconsistent resource AppID.
+INVALIDPARAMETER_CAMRESOURCEBELONGTODIFFERENTUSER = 'InvalidParameter.CamResourceBelongToDifferentUser'
+
+# Incorrect six-segment resource parameter.
+INVALIDPARAMETER_CAMRESOURCESIXSTAGEERROR = 'InvalidParameter.CamResourceSixStageError'
+
+# The domain name has already been associated with this tag.
+INVALIDPARAMETER_CAMTAGKEYALREADYATTACHED = 'InvalidParameter.CamTagKeyAlreadyAttached'
+
+# Invalid characters in the tag key.
+INVALIDPARAMETER_CAMTAGKEYILLEGAL = 'InvalidParameter.CamTagKeyIllegal'
+
+# The tag key does not exist.
+INVALIDPARAMETER_CAMTAGKEYNOTEXIST = 'InvalidParameter.CamTagKeyNotExist'
+
+# Invalid characters in the tag value.
+INVALIDPARAMETER_CAMTAGVALUEILLEGAL = 'InvalidParameter.CamTagValueIllegal'
+
 # The certificate information is invalid or does not exist. Please check and try again.
 INVALIDPARAMETER_CDNCERTINFONOTFOUND = 'InvalidParameter.CdnCertInfoNotFound'
 
@@ -104,9 +122,18 @@ INVALIDPARAMETER_CDNCONFIGINVALIDCACHE = 'InvalidParameter.CdnConfigInvalidCache
 # Invalid domain name. Please make sure the domain name is valid.
 INVALIDPARAMETER_CDNCONFIGINVALIDHOST = 'InvalidParameter.CdnConfigInvalidHost'
 
+# Invalid tag configuration.
+INVALIDPARAMETER_CDNCONFIGINVALIDTAG = 'InvalidParameter.CdnConfigInvalidTag'
+
+# Failed to add the domain name. Please make sure to specify a tag for the domain name.
+INVALIDPARAMETER_CDNCONFIGTAGREQUIRED = 'InvalidParameter.CdnConfigTagRequired'
+
 # The domain name is configured with special configurations, please submit a ticket.
 INVALIDPARAMETER_CDNHOSTHASSPECIALCONFIG = 'InvalidParameter.CdnHostHasSpecialConfig'
 
+# This domain name belongs to another account. You are not allowed o connect it to CDN.
+INVALIDPARAMETER_CDNHOSTINTERNALHOST = 'InvalidParameter.CdnHostInternalHost'
+
 # Incorrect intermediate server configuration.
 INVALIDPARAMETER_CDNHOSTINVALIDMIDDLECONFIG = 'InvalidParameter.CdnHostInvalidMiddleConfig'
 
@@ -116,6 +143,12 @@ INVALIDPARAMETER_CDNHOSTINVALIDPARAM = 'InvalidParameter.CdnHostInvalidParam'
 # Invalid domain name status.
 INVALIDPARAMETER_CDNHOSTINVALIDSTATUS = 'InvalidParameter.CdnHostInvalidStatus'
 
+# It is a COS origin domain name. Please go to the COS console to enable "Default CDN Acceleration Domain".
+INVALIDPARAMETER_CDNHOSTISCOSDEFAULTACCESS = 'InvalidParameter.CdnHostIsCosDefaultAccess'
+
+# The domain name is too long.
+INVALIDPARAMETER_CDNHOSTTOOLONGHOST = 'InvalidParameter.CdnHostTooLongHost'
+
 # Internal API error. Please submit a ticket for troubleshooting.
 INVALIDPARAMETER_CDNINTERFACEERROR = 'InvalidParameter.CdnInterfaceError'
 
@@ -221,6 +254,24 @@ INVALIDPARAMETER_SCDNLOGTASKNOTFOUNDORNOTFAIL = 'InvalidParameter.ScdnLogTaskNot
 # Incorrect time range
 INVALIDPARAMETER_SCDNLOGTASKTIMERANGEINVALID = 'InvalidParameter.ScdnLogTaskTimeRangeInvalid'
 
+# The number of resource arrays exceeds the upper limit.
+LIMITEXCEEDED_CAMRESOURCEARRAYTOOLONG = 'LimitExceeded.CamResourceArrayTooLong'
+
+# The number of tag keys exceeds the upper limit. Each resource can have up to 50 tag keys.
+LIMITEXCEEDED_CAMRESOURCETOOMANYTAGKEY = 'LimitExceeded.CamResourceTooManyTagKey'
+
+# The tag key length exceeds the upper limit.
+LIMITEXCEEDED_CAMTAGKEYTOOLONG = 'LimitExceeded.CamTagKeyTooLong'
+
+# The number of tag values exceeds the upper limit. Each tag key can have up to 1,000 tag values.
+LIMITEXCEEDED_CAMTAGKEYTOOMANYTAGVALUE = 'LimitExceeded.CamTagKeyTooManyTagValue'
+
+# The number of bound tags exceeds the limit.
+LIMITEXCEEDED_CAMTAGQUOTAEXCEEDLIMIT = 'LimitExceeded.CamTagQuotaExceedLimit'
+
+# The number of keys exceeds the upper limit. Each user can have up to 1,000 different keys.
+LIMITEXCEEDED_CAMUSERTOOMANYTAGKEY = 'LimitExceeded.CamUserTooManyTagKey'
+
 # Too frequent queries on IP ownership.
 LIMITEXCEEDED_CDNCALLINGQUERYIPTOOOFTEN = 'LimitExceeded.CdnCallingQueryIpTooOften'
 
@@ -254,6 +305,9 @@ LIMITEXCEEDED_CDNPUSHEXCEEDDAYLIMIT = 'LimitExceeded.CdnPushExceedDayLimit'
 # The number of IPs to be queried exceeds the limit.
 LIMITEXCEEDED_CDNQUERYIPBATCHTOOMANY = 'LimitExceeded.CdnQueryIpBatchTooMany'
 
+# The number of domain names under the account has reached the upper limit. Please submit a ticket for assistance.
+LIMITEXCEEDED_CDNUSERTOOMANYHOSTS = 'LimitExceeded.CdnUserTooManyHosts'
+
 # The log size exceeds the limit.
 LIMITEXCEEDED_CLSLOGSIZEEXCEED = 'LimitExceeded.ClsLogSizeExceed'
 
@@ -266,12 +320,18 @@ LIMITEXCEEDED_CLSTOPICEXCEED = 'LimitExceeded.ClsTopicExceed'
 # Daily task quota exceeded
 LIMITEXCEEDED_SCDNLOGTASKEXCEEDDAYLIMIT = 'LimitExceeded.ScdnLogTaskExceedDayLimit'
 
+# The domain name conflicts with an existing domain name in the system.
+RESOURCEINUSE_CDNCONFLICTHOSTEXISTS = 'ResourceInUse.CdnConflictHostExists'
+
 # Domain name already exists.
 RESOURCEINUSE_CDNHOSTEXISTS = 'ResourceInUse.CdnHostExists'
 
 # CDN resources are being operated.
 RESOURCEINUSE_CDNOPINPROGRESS = 'ResourceInUse.CdnOpInProgress'
 
+# The tag key does not exist.
+RESOURCENOTFOUND_CAMTAGKEYNOTEXIST = 'ResourceNotFound.CamTagKeyNotExist'
+
 # Unable to find the domain name. Please make sure the domain name is correct.
 RESOURCENOTFOUND_CDNHOSTNOTEXISTS = 'ResourceNotFound.CdnHostNotExists'
 
@@ -302,9 +362,18 @@ RESOURCEUNAVAILABLE_CDNHOSTBELONGSTOOTHERSINMAINLAND = 'ResourceUnavailable.CdnH
 # The domain name has been connected to the service region outside Mainland China. If you need to switch the service region to "Global", please verify its ownership for domain name retrieval.
 RESOURCEUNAVAILABLE_CDNHOSTBELONGSTOOTHERSINOVERSEAS = 'ResourceUnavailable.CdnHostBelongsToOthersInOverseas'
 
+# The DSA feature is enabled for the domain name.
+RESOURCEUNAVAILABLE_CDNHOSTEXISTSINDSA = 'ResourceUnavailable.CdnHostExistsInDsa'
+
+# The domain name has been connected in the TCB console.
+RESOURCEUNAVAILABLE_CDNHOSTEXISTSINTCB = 'ResourceUnavailable.CdnHostExistsInTcb'
+
 # The domain name is locked.
 RESOURCEUNAVAILABLE_CDNHOSTISLOCKED = 'ResourceUnavailable.CdnHostIsLocked'
 
+# The domain name is not compliant and cannot be connected.
+RESOURCEUNAVAILABLE_CDNHOSTISMALICIOUS = 'ResourceUnavailable.CdnHostIsMalicious'
+
 # Domain name is still in use.
 RESOURCEUNAVAILABLE_CDNHOSTISNOTOFFLINE = 'ResourceUnavailable.CdnHostIsNotOffline'
 
@@ -314,6 +383,9 @@ RESOURCEUNAVAILABLE_CDNHOSTISNOTONLINE = 'ResourceUnavailable.CdnHostIsNotOnline
 # ICP filing is required for the domain name and the synchronization takes 2 hours. If it is already filed, please try later.
 RESOURCEUNAVAILABLE_CDNHOSTNOICP = 'ResourceUnavailable.CdnHostNoIcp'
 
+# The domain name has been connected to VOD. To access CDN, please delete it from VOD first.
+RESOURCEUNAVAILABLE_HOSTEXISTINVOD = 'ResourceUnavailable.HostExistInVod'
+
 # The SCDN service is not activated. Please purchase or renew an SCDN packet and try again.
 RESOURCEUNAVAILABLE_SCDNUSERNOPACKAGE = 'ResourceUnavailable.ScdnUserNoPackage'
 
@@ -326,9 +398,18 @@ UNAUTHORIZEDOPERATION_CDNCAMUNAUTHORIZED = 'UnauthorizedOperation.CdnCamUnauthor
 # This account is not authorized to activate CLS.
 UNAUTHORIZEDOPERATION_CDNCLSNOTREGISTERED = 'UnauthorizedOperation.CdnClsNotRegistered'
 
+# The domain name has not been verified.
+UNAUTHORIZEDOPERATION_CDNDOMAINRECORDNOTVERIFIED = 'UnauthorizedOperation.CdnDomainRecordNotVerified'
+
+# The domain name already exists in the system. Please submit a ticket.
+UNAUTHORIZEDOPERATION_CDNHOSTEXISTSININTERNAL = 'UnauthorizedOperation.CdnHostExistsInInternal'
+
 # The domain name is not compliant and cannot be connected.
 UNAUTHORIZEDOPERATION_CDNHOSTINICPBLACKLIST = 'UnauthorizedOperation.CdnHostInIcpBlacklist'
 
+# This domain name belongs to another account, and you do not have permission to connect it.
+UNAUTHORIZEDOPERATION_CDNHOSTISOWNEDBYOTHER = 'UnauthorizedOperation.CdnHostIsOwnedByOther'
+
 # The domain name has been connected by another account. For more information, please submit a ticket.
 UNAUTHORIZEDOPERATION_CDNHOSTISUSEDBYOTHER = 'UnauthorizedOperation.CdnHostIsUsedByOther'
 
