@@ -29,6 +29,9 @@ INTERNALERROR = 'InternalError'
 # Invalid parameter.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# The topic name is duplicate.
+INVALIDPARAMETER_TOPICEXIST = 'InvalidParameter.TopicExist'
+
 # Invalid parameter value.
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
@@ -80,6 +83,9 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # The resource is unavailable.
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# Disk resources are unavailable on the broker.
+RESOURCEUNAVAILABLE_KAFKASTORAGEERROR = 'ResourceUnavailable.KafkaStorageError'
+
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
