@@ -215,10 +215,10 @@ INVALIDPARAMETERVALUE_INVALIDINSTANCETYPECONFIGID = 'InvalidParameterValue.Inval
 # The billing mode is invalid.
 INVALIDPARAMETERVALUE_INVALIDINTERNETCHARGETYPE = 'InvalidParameterValue.InvalidInternetChargeType'
 
-# The key ID is invalid.
+# Invalid key ID.
 INVALIDPARAMETERVALUE_INVALIDKEYPAIRID = 'InvalidParameterValue.InvalidKeyPairId'
 
-# The key name is exceptional.
+# Invalid key name.
 INVALIDPARAMETERVALUE_INVALIDKEYPAIRNAME = 'InvalidParameterValue.InvalidKeyPairName'
 
 # The number of CLB instances is invalid.
@@ -257,6 +257,9 @@ INVALIDPARAMETERVALUE_INVALIDSNAPSHOT = 'InvalidParameterValue.InvalidSnapshot'
 # InvalidParameterValue.InvalidSnapshotId
 INVALIDPARAMETERVALUE_INVALIDSNAPSHOTID = 'InvalidParameterValue.InvalidSnapshotId'
 
+# The node does not exist in this subnet.
+INVALIDPARAMETERVALUE_INVALIDSUBNETINZONE = 'InvalidParameterValue.InvalidSubnetInZone'
+
 # The system disk size is invalid.
 INVALIDPARAMETERVALUE_INVALIDSYSTEMDISKSIZE = 'InvalidParameterValue.InvalidSystemDiskSize'
 
@@ -308,6 +311,9 @@ INVALIDPARAMETERVALUE_RESERVED = 'InvalidParameterValue.Reserved'
 # The specified CIDR block conflicts with another subnet in the same VPC.
 INVALIDPARAMETERVALUE_SUBNETCONFLICT = 'InvalidParameterValue.SubnetConflict'
 
+# 
+INVALIDPARAMETERVALUE_SUBNETNOTEXIST = 'InvalidParameterValue.SubnetNotExist'
+
 # The subnet IP range is invalid.
 INVALIDPARAMETERVALUE_SUBNETRANGE = 'InvalidParameterValue.SubnetRange'
 
@@ -440,6 +446,9 @@ RESOURCEUNAVAILABLE_INSTANCENOTRUNNING = 'ResourceUnavailable.InstanceNotRunning
 # CLB instances have been sold out.
 RESOURCESSOLDOUT_LOADBALANCERSOLDOUT = 'ResourcesSoldOut.LoadBalancerSoldOut'
 
+# 
+RESOURCESSOLDOUT_SPECIFIEDINSTANCETYPE = 'ResourcesSoldOut.SpecifiedInstanceType'
+
 # You don't have the permission to perform this operation.
 UNAUTHORIZEDOPERATION_FORBIDDENOPERATION = 'UnauthorizedOperation.ForbiddenOperation'
 
