@@ -23,6 +23,21 @@ FAILEDOPERATION_CHECKIFSUPPORTPODSTRETCH = 'FailedOperation.CheckIfSupportPodStr
 # Duplicate order. Please check the EMR console.
 FAILEDOPERATION_DUPLICATEORDERNOTALLOWED = 'FailedOperation.DuplicateOrderNotAllowed'
 
+# Failed to query the CAM role.
+FAILEDOPERATION_GETCAMROLEFAILED = 'FailedOperation.GetCamRoleFailed'
+
+# Failed to call the CAM service.
+FAILEDOPERATION_GETCAMSERVERFAILED = 'FailedOperation.GetCamServerFailed'
+
+# 
+FAILEDOPERATION_GETCVMCONFIGQUOTAFAILED = 'FailedOperation.GetCvmConfigQuotaFailed'
+
+# 
+FAILEDOPERATION_GETCVMSERVERFAILED = 'FailedOperation.GetCvmServerFailed'
+
+# 
+FAILEDOPERATION_GETTRADESERVERFAILED = 'FailedOperation.GetTradeServerFailed'
+
 # Operation failed. The pods are not supported.
 FAILEDOPERATION_NOTSUPPORTPOD = 'FailedOperation.NotSupportPod'
 
@@ -95,6 +110,9 @@ INTERNALERROR_WOODSERVERERROR = 'InternalError.WoodServerError'
 # Invalid parameter.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# Parameter error.
+INVALIDPARAMETER_APPIDRESOURCENOTMATCH = 'InvalidParameter.AppIdResourceNotMatch'
+
 # Incorrect display policy.
 INVALIDPARAMETER_DISPLAYSTRATEGYNOTMATCH = 'InvalidParameter.DisplayStrategyNotMatch'
 
@@ -164,6 +182,9 @@ INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'
 # Invalid model.
 INVALIDPARAMETER_INVALIDINSTANCETYPE = 'InvalidParameter.InvalidInstanceType'
 
+# Invalid process task.
+INVALIDPARAMETER_INVALIDJOBFLOW = 'InvalidParameter.InvalidJobFlow'
+
 # Invalid login settings.
 INVALIDPARAMETER_INVALIDLOGINSETTING = 'InvalidParameter.InvalidLoginSetting'
 
@@ -179,6 +200,9 @@ INVALIDPARAMETER_INVALIDMETATYPE = 'InvalidParameter.InvalidMetaType'
 # Invalid target specification.
 INVALIDPARAMETER_INVALIDMODIFYSPEC = 'InvalidParameter.InvalidModifySpec'
 
+# Incorrect node type.
+INVALIDPARAMETER_INVALIDNODEFLAG = 'InvalidParameter.InvalidNodeFlag'
+
 # Invalid `NodeType`.
 INVALIDPARAMETER_INVALIDNODETYPE = 'InvalidParameter.InvalidNodeType'
 
@@ -317,6 +341,9 @@ RESOURCEINSUFFICIENT_INSTANCEINSUFFICIENT = 'ResourceInsufficient.InstanceInsuff
 # The instance was not found.
 RESOURCENOTFOUND_CLUSTERNOTFOUND = 'ResourceNotFound.ClusterNotFound'
 
+# Unable to find the specified CVM instance.
+RESOURCENOTFOUND_CVMINSTANCENOTFOUND = 'ResourceNotFound.CvmInstanceNotFound'
+
 # No hardware information found.
 RESOURCENOTFOUND_HARDWAREINFONOTFOUND = 'ResourceNotFound.HardwareInfoNotFound'
 
