@@ -68,7 +68,7 @@ FAILEDOPERATION_COSBUCKETNOTEXIST = 'FailedOperation.CosBucketNotExist'
 # You don’t have permission to access the COS bucket.
 FAILEDOPERATION_COSBUCKETNOTPERMISSION = 'FailedOperation.CosBucketNotPermission'
 
-# The COS role does not exist.
+# The COS role does not exist. Please go to the “Feature Configuration > Live Screencapture & Porn Detection” page of the CSS console to grant the permission.
 FAILEDOPERATION_COSROLENOTEXISTS = 'FailedOperation.CosRoleNotExists'
 
 # The domain name cannot be deleted because it incurred traffic in the last 2 days and is in locked state.
@@ -323,6 +323,12 @@ INVALIDPARAMETER_CLOUDCRTIDERROR = 'InvalidParameter.CloudCrtIdError'
 # The gifted Tencent Cloud domain name has expired.
 INVALIDPARAMETER_CLOUDDOMAINISSTOP = 'InvalidParameter.CloudDomainIsStop'
 
+# 
+INVALIDPARAMETER_CONFINUSED = 'InvalidParameter.ConfInUsed'
+
+# 
+INVALIDPARAMETER_CONFNOTFOUND = 'InvalidParameter.ConfNotFound'
+
 # The certificate is in use.
 INVALIDPARAMETER_CRTDATEINUSING = 'InvalidParameter.CrtDateInUsing'
 
@@ -383,6 +389,12 @@ INVALIDPARAMETER_INVALIDCROPPARAM = 'InvalidParameter.InvalidCropParam'
 # Invalid layer parameter.
 INVALIDPARAMETER_INVALIDLAYERPARAM = 'InvalidParameter.InvalidLayerParam'
 
+# 
+INVALIDPARAMETER_INVALIDMIXINPUTPARAM = 'InvalidParameter.InvalidMixInputParam'
+
+# 
+INVALIDPARAMETER_INVALIDOUTPUTPARAM = 'InvalidParameter.InvalidOutputParam'
+
 # The output stream ID is already used.
 INVALIDPARAMETER_INVALIDOUTPUTSTREAMID = 'InvalidParameter.InvalidOutputStreamID'
 
@@ -419,6 +431,12 @@ INVALIDPARAMETER_MPPLUGINNOUSE = 'InvalidParameter.MpPluginNoUse'
 # Other errors.
 INVALIDPARAMETER_OTHERERROR = 'InvalidParameter.OtherError'
 
+# 
+INVALIDPARAMETER_PROCESSORALREADYEXIST = 'InvalidParameter.ProcessorAlreadyExist'
+
+# 
+INVALIDPARAMETER_RULENOTFOUND = 'InvalidParameter.RuleNotFound'
+
 # The output stream of the same session has changed.
 INVALIDPARAMETER_SESSIONOUTPUTSTREAMCHANGED = 'InvalidParameter.SessionOutputStreamChanged'
 
@@ -479,6 +497,9 @@ RESOURCENOTFOUND_DOMAINNORECORD = 'ResourceNotFound.DomainNoRecord'
 # The domain name does not exist or is not matched.
 RESOURCENOTFOUND_DOMAINNOTEXIST = 'ResourceNotFound.DomainNotExist'
 
+# 
+RESOURCENOTFOUND_EMPTYDATA = 'ResourceNotFound.EmptyData'
+
 # You are blocked.
 RESOURCENOTFOUND_FORBIDSERVICE = 'ResourceNotFound.ForbidService'
 
