@@ -32,7 +32,7 @@ FAILEDOPERATION_CLASSNOFOUND = 'FailedOperation.ClassNoFound'
 # Operation failed: unsupported cover type.
 FAILEDOPERATION_COVERTYPE = 'FailedOperation.CoverType'
 
-# 
+# Operation failed: The database operation failed.
 FAILEDOPERATION_DBERROR = 'FailedOperation.DBError'
 
 # You cannot modify the settings of the domain name as it is being deployed.
@@ -53,9 +53,6 @@ FAILEDOPERATION_MEDIATYPE = 'FailedOperation.MediaType'
 # Network error.
 FAILEDOPERATION_NETWORKERROR = 'FailedOperation.NetWorkError'
 
-# No need to reduce the bitrate.
-FAILEDOPERATION_NONEEDTOREDUCEMEDIABITRATE = 'FailedOperation.NoNeedToReduceMediaBitrate'
-
 # Operation failed: the parent category ID does not exist.
 FAILEDOPERATION_PARENTIDNOFOUND = 'FailedOperation.ParentIdNoFound'
 
