@@ -137,12 +137,12 @@ INVALIDPARAMETERVALUE_ADDRESSNOTAPPLICABLE = 'InvalidParameterValue.AddressNotAp
 # This IP address is not a CalcIP (device IP).
 INVALIDPARAMETERVALUE_ADDRESSNOTCALCIP = 'InvalidParameterValue.AddressNotCalcIP'
 
-# This IP is not an EIP.
-INVALIDPARAMETERVALUE_ADDRESSNOTEIP = 'InvalidParameterValue.AddressNotEIP'
-
 # Unable to find the address.
 INVALIDPARAMETERVALUE_ADDRESSNOTFOUND = 'InvalidParameterValue.AddressNotFound'
 
+# 
+INVALIDPARAMETERVALUE_ADDRESSTYPECONFLICT = 'InvalidParameterValue.AddressTypeConflict'
+
 # The bandwidth exceeds the limit.
 INVALIDPARAMETERVALUE_BANDWIDTHOUTOFRANGE = 'InvalidParameterValue.BandwidthOutOfRange'
 
@@ -263,7 +263,7 @@ INVALIDPARAMETERVALUE_NATGATEWAYDNATRULENOTEXISTS = 'InvalidParameterValue.NatGa
 # The private IP of the DNAT translation rule must be an IP used by the ENI of the virtual machine.
 INVALIDPARAMETERVALUE_NATGATEWAYDNATRULEPIPNEEDVM = 'InvalidParameterValue.NatGatewayDnatRulePipNeedVm'
 
-# 
+# The DNAT rule of the NAT gateway to add already exists.
 INVALIDPARAMETERVALUE_NATGATEWAYDNATRULEREPEATED = 'InvalidParameterValue.NatGatewayDnatRuleRepeated'
 
 # The SNAT forwarding rule of the NAT gateway does not exist.
@@ -317,6 +317,9 @@ INVALIDPARAMETERVALUE_RESOURCENOTFOUND = 'InvalidParameterValue.ResourceNotFound
 # The resource does not support this operation.
 INVALIDPARAMETERVALUE_RESOURCENOTSUPPORT = 'InvalidParameterValue.ResourceNotSupport'
 
+# 
+INVALIDPARAMETERVALUE_STOPCHARGINGINSTANCEINUSE = 'InvalidParameterValue.StopChargingInstanceInUse'
+
 # Subnet CIDR conflict.
 INVALIDPARAMETERVALUE_SUBNETCONFLICT = 'InvalidParameterValue.SubnetConflict'
 
@@ -440,6 +443,9 @@ LIMITEXCEEDED_ATTACHEDSNAPSHOTPOLICYEXCEEDED = 'LimitExceeded.AttachedSnapshotPo
 # Exceeded the upper limit of the bandwidth package quota.
 LIMITEXCEEDED_BANDWIDTHPACKAGEQUOTA = 'LimitExceeded.BandwidthPackageQuota'
 
+# 
+LIMITEXCEEDED_BANDWIDTHPACKAGERESOURCEQUOTA = 'LimitExceeded.BandwidthPackageResourceQuota'
+
 # Run out of the chances to change the IP.
 LIMITEXCEEDED_CHANGEADDRESSQUOTA = 'LimitExceeded.ChangeAddressQuota'
 
@@ -563,12 +569,15 @@ UNKNOWNPARAMETER_WITHGUESS = 'UnknownParameter.WithGuess'
 # Unsupported operation.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
-# 
+# This account is not supported.
 UNSUPPORTEDOPERATION_ACCOUNTNOTSUPPORTED = 'UnsupportedOperation.AccountNotSupported'
 
 # The port does not exist.
 UNSUPPORTEDOPERATION_ACTIONNOTFOUND = 'UnsupportedOperation.ActionNotFound'
 
+# 
+UNSUPPORTEDOPERATION_ADDRESSIPNOTSUPPORTINSTANCE = 'UnsupportedOperation.AddressIpNotSupportInstance'
+
 # This operation is not supported by the IP address status.
 UNSUPPORTEDOPERATION_ADDRESSSTATUSNOTPERMIT = 'UnsupportedOperation.AddressStatusNotPermit'
 
@@ -578,7 +587,7 @@ UNSUPPORTEDOPERATION_APPIDMISMATCH = 'UnsupportedOperation.AppIdMismatch'
 # The APPId doesn't exist.
 UNSUPPORTEDOPERATION_APPIDNOTFOUND = 'UnsupportedOperation.AppIdNotFound'
 
-# 
+# The NAT gateway route already exists in another VPC added to the CCN instance.
 UNSUPPORTEDOPERATION_ASSOCIATEDVPCOFCCNHADNATROUTE = 'UnsupportedOperation.AssociatedVpcOfCcnHadNatRoute'
 
 # The EIP is already bound to a CVM.
@@ -623,7 +632,7 @@ UNSUPPORTEDOPERATION_CDCSUBNETNOTSUPPORTUNLOCALGATEWAY = 'UnsupportedOperation.C
 # The instance has already been bound to the VPC.
 UNSUPPORTEDOPERATION_CLASSICINSTANCEIDALREADYEXISTS = 'UnsupportedOperation.ClassicInstanceIdAlreadyExists'
 
-# 
+# Reached the upper limit of security group policies of the load balancer.
 UNSUPPORTEDOPERATION_CLBPOLICYEXCEEDLIMIT = 'UnsupportedOperation.ClbPolicyExceedLimit'
 
 # Public network CLB does not support this policy.
@@ -653,7 +662,7 @@ UNSUPPORTEDOPERATION_DIRECTCONNECTGATEWAYISUPDATINGCOMMUNITY = 'UnsupportedOpera
 # The specified routing policy cannot be re-published to CCN. Please first withdraw it from CCN.
 UNSUPPORTEDOPERATION_DISABLEDNOTIFYCCN = 'UnsupportedOperation.DisabledNotifyCcn'
 
-# 
+# To create a DPDK NAT flow log, the collection type must be `All`.
 UNSUPPORTEDOPERATION_DPDKNATFLOWLOGONLYSUPPORTALLTRAFFICTYPE = 'UnsupportedOperation.DpdkNatFlowLogOnlySupportAllTrafficType'
 
 # The security group policies are repeated.
@@ -674,6 +683,9 @@ UNSUPPORTEDOPERATION_ENABLEMULTICAST = 'UnsupportedOperation.EnableMulticast'
 # The endpoint service itself cannot be set as the endpoint.
 UNSUPPORTEDOPERATION_ENDPOINTSERVICE = 'UnsupportedOperation.EndPointService'
 
+# 
+UNSUPPORTEDOPERATION_FLOWLOGINSTANCEEXISTED = 'UnsupportedOperation.FlowLogInstanceExisted'
+
 # Unable to create a flow log: the current ENI is bound with a KO model.
 UNSUPPORTEDOPERATION_FLOWLOGSNOTSUPPORTKOINSTANCEENI = 'UnsupportedOperation.FlowLogsNotSupportKoInstanceEni'
 
@@ -869,6 +881,9 @@ UNSUPPORTEDOPERATION_SPECIALENDPOINTSERVICE = 'UnsupportedOperation.SpecialEndPo
 # The relayed ENI does not support this operation.
 UNSUPPORTEDOPERATION_SUBENINOTSUPPORTTRUNKING = 'UnsupportedOperation.SubEniNotSupportTrunking'
 
+# 
+UNSUPPORTEDOPERATION_SUBNETNOTEXISTS = 'UnsupportedOperation.SubnetNotExists'
+
 # System route. Operation is prohibited.
 UNSUPPORTEDOPERATION_SYSTEMROUTE = 'UnsupportedOperation.SystemRoute'
 
@@ -920,7 +935,7 @@ UNSUPPORTEDOPERATION_VERSIONMISMATCH = 'UnsupportedOperation.VersionMismatch'
 # The resources are not in the same VPC.
 UNSUPPORTEDOPERATION_VPCMISMATCH = 'UnsupportedOperation.VpcMismatch'
 
-# 
+# Operation failed: The tunnel is not available now.
 UNSUPPORTEDOPERATION_VPNCONNINVALIDSTATE = 'UnsupportedOperation.VpnConnInvalidState'
 
 # 
